pypka.delphi4py package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pypka.delphi4py.readFiles
   pypka.delphi4py.rundelphi

Submodules
----------

pypka.delphi4py.delphi4py module
--------------------------------

.. automodule:: pypka.delphi4py.delphi4py
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pypka.delphi4py
   :members:
   :undoc-members:
   :show-inheritance:
